WASC_URL = 'http://projects.webappsec.org/w/page'

WASC_ID_TO_URL = {42: WASC_URL + '/13246913/Abuse%20of%20Functionality',
                  11: WASC_URL + '/13246915/Brute%20Force',
                  7:  WASC_URL + '/13246916/Buffer%20Overflow',
                  12: WASC_URL + '/13246917/Content%20Spoofing',
                  18: WASC_URL + '/13246918/Credential%20and%20Session%20Prediction',
                  8:  WASC_URL + '/13246920/Cross%20Site%20Scripting',
                  9:  WASC_URL + '/13246919/Cross%20Site%20Request%20Forgery',
                  10: WASC_URL + '/13246921/Denial%20of%20Service',
                  45: WASC_URL + '/13246925/Fingerprinting',
                  27: WASC_URL + '/13246930/HTTP%20Response%20Smuggling',
                  25: WASC_URL + '/13246931/HTTP%20Response%20Splitting',
                  26: WASC_URL + '/13246928/HTTP%20Request%20Smuggling',
                  24: WASC_URL + '/13246929/HTTP%20Request%20Splitting',
                  3:  WASC_URL + '/13246946/Integer%20Overflows',
                  6:  WASC_URL + '/13246926/Format%20String',
                  29: WASC_URL + '/13246947/LDAP%20Injection',
                  30: WASC_URL + '/13246948/Mail%20Command%20Injection',
                  28: WASC_URL + '/13246949/Null%20Byte%20Injection',
                  31: WASC_URL + '/13246950/OS%20Commanding',
                  33: WASC_URL + '/13246952/Path%20Traversal',
                  34: WASC_URL + '/13246953/Predictable%20Resource%20Location',
                  32: WASC_URL + '/13246956/Routing%20Detour',
                  37: WASC_URL + '/13246960/Session%20Fixation',
                  35: WASC_URL + '/13246962/SOAP%20Array%20Abuse',
                  36: WASC_URL + '/13246964/SSI%20Injection',
                  19: WASC_URL + '/13246963/SQL%20Injection',
                  38: WASC_URL + '/13246981/URL%20Redirector%20Abuse',
                  39: WASC_URL + '/13247005/XPath%20Injection',
                  41: WASC_URL + '/13247001/XML%20Attribute%20Blowup',
                  43: WASC_URL + '/13247003/XML%20External%20Entities',
                  44: WASC_URL + '/13247002/XML%20Entity%20Expansion',
                  23: WASC_URL + '/13247004/XML%20Injection',
                  46: WASC_URL + '/13247006/XQuery%20Injection',
                  15: WASC_URL + '/13246914/Application%20Misconfiguration',
                  16: WASC_URL + '/13246922/Directory%20Indexing',
                  17: WASC_URL + '/13246932/Improper%20Filesystem%20Permissions',
                  20: WASC_URL + '/13246933/Improper%20Input%20Handling',
                  22: WASC_URL + '/13246934/Improper%20Output%20Handling',
                  13: WASC_URL + '/13246936/Information%20Leakage',
                  48: WASC_URL + '/13246937/Insecure%20Indexing',
                  21: WASC_URL + '/13246938/Insufficient%20Anti-automation',
                  1:  WASC_URL + '/13246939/Insufficient%20Authentication',
                  2:  WASC_URL + '/13246940/Insufficient%20Authorization',
                  49: WASC_URL + '/13246942/Insufficient%20Password%20Recovery',
                  40: WASC_URL + '/13246943/Insufficient%20Process%20Validation',
                  47: WASC_URL + '/13246944/Insufficient%20Session%20Expiration',
                  4:  WASC_URL + '/13246945/Insufficient%20Transport%20Layer%20Protection',
                  14: WASC_URL + '/13246959/Server%20Misconfiguration'
                  }
